#!/usr/bin Rscript
#Call the script like this: Rscript plot_validation.R outfile_name firm5_1_perc_id.txt firm5_2_perc_id.txt 

options(warn=1)
rm(list=ls())
require("ggplot2")
require("gridExtra")

plot_function <- function(x) {
	 data <- read.table(x, h=T)
	 split_name <- strsplit(x,"_")
	 sdp <- paste0(c(split_name[[1]][1],split_name[[1]][2]), collapse='_')
	 df_1 <- subset(data, data$Closest_SDP_db == sdp)
	 df_2 <- subset(data, data$Closest_SDP_db != sdp)
	 length_sdp <- length(df_1[,1])
	 length_other <- length(df_2[,1])
	 tot_length = length_sdp + length_other
	 plot_title <- paste(sdp, ": ",tot_length, sep="")
	 all_perc <- c(df_1$Perc_id, df_2$Perc_id)
	 all_names <- c(rep(sdp,length_sdp), rep("other", length_other))
	 melt.df <- data.frame(all_perc, all_names)
	 melt.df$all_names <- factor(melt.df$all_names, levels=c(sdp, "other"))
	 p <- ggplot() + geom_density(data=melt.df, aes(x=all_perc, group=all_names, fill=all_names), alpha=0.5)+ylim(0,0.65) + xlim(60,100) +xlab("% identity") + ggtitle(plot_title) + scale_fill_manual(values=c("blue","grey")) +theme(legend.position="none")
	 return(p)	 
}

##data acquisition

Args <- commandArgs(trailingOnly=TRUE)
infiles <- Args[2:length(Args)]
plots <- lapply(infiles, plot_function)

outfile <- Args[1]
cairo_pdf(outfile, h=9.5,w=7.3)
do.call("grid.arrange", plots)
dev.off()

